@@ -1,6 +1,6 @@
 /* gnome-stones - main.c
  *
- * Time-stamp: <1999/01/10 05:56:18 ndf>
+ * Time-stamp: <1999/01/17 15:16:30 carsten>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -91,33 +91,8 @@ static char *default_message= N_("Gnome-Stones (c) 1998 Carsten Schaar");
 /* Commandline options.  */
 
 
-static void 
-parse_func (poptContext ctx,
-	    enum poptCallbackReason reason,
-	    const struct poptOption *opt,
-	    const char *arg, void *data)
-{
-  int key = opt ? opt->val : 0;
-
-  printf ("Parsing commandline: key %i\n", key);
-
-  if (key == 1)
-    {
-      printf ("\"--discard-file %s\" found\n", arg);
-      /* Option: --discard-file  */
-      discard_session_file (arg);
-
-      exit (0);
-    }
-
-}
-
-
 /* Command-line arguments understood by this module.  */
 static const struct poptOption options[] = {
-  {NULL, '\0', POPT_ARG_CALLBACK, parse_func, 0, NULL, NULL},
-  {"discard-file", '\0', POPT_ARG_STRING, NULL, 1, 
-   N_("Config file to discard"), N_("CONFIG FILE")},
   {NULL, '\0', 0, NULL, 0}
 };
 
@@ -1165,11 +1140,6 @@ about_cb (GtkWidget *widget, gpointer data)
 /* Menu definitions */
 
 
-static GnomeUIInfo file_menu[]= {
-  GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb, NULL),
-  GNOMEUIINFO_END
-};
-
 static GnomeUIInfo game_menu[]= {
   GNOMEUIINFO_MENU_NEW_GAME_ITEM(game_start_cb, NULL),
 
@@ -1177,6 +1147,10 @@ static GnomeUIInfo game_menu[]= {
 
   GNOMEUIINFO_MENU_SCORES_ITEM(show_scores_cb, NULL),
 
+  GNOMEUIINFO_SEPARATOR,
+
+  GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb, NULL),
+
   GNOMEUIINFO_END
 };
 
@@ -1193,7 +1167,6 @@ static GnomeUIInfo settings_menu[]= {
 
 static GnomeUIInfo main_menu[]= 
 {
-  GNOMEUIINFO_MENU_FILE_TREE(file_menu),
   GNOMEUIINFO_MENU_GAME_TREE(game_menu),
   GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
   GNOMEUIINFO_MENU_HELP_TREE(help_menu),
@@ -1345,6 +1318,7 @@ main (int argc, char *argv[])
 
   /* That's what a gnome application needs:  */
   app= gnome_app_new ("gnome-stones", _("Gnome-Stones"));
+  gtk_widget_realize(app);
   gtk_window_set_policy  (GTK_WINDOW (app), FALSE, FALSE, TRUE);
   gtk_window_set_wmclass (GTK_WINDOW (app), "gnome-stones", "main");
 
