@@ -59,8 +59,8 @@ void show_face(GtkWidget *pm)
 
 void quit_game(GtkWidget *widget, gpointer data)
 {
-        gtk_widget_destroy(window);
-        gtk_main_quit();
+//	gtk_widget_destroy(window);
+	gtk_main_quit();
 }
 
 void set_flabel(GtkMineField *mfield)
@@ -268,18 +268,18 @@ void setup_game(GtkWidget *widget, gpointer data)
 	
         if (setupdialog) return;
 
-	setupdialog = gtk_window_new(GTK_WINDOW_DIALOG);
+	setupdialog = gnome_dialog_new (_("Gnome Mines setup"),
+			GNOME_STOCK_BUTTON_OK, GNOME_STOCK_BUTTON_CANCEL,
+			NULL);
+	gnome_dialog_set_parent (GNOME_DIALOG (setupdialog),
+			GTK_WINDOW (window));
 
-	gtk_container_border_width(GTK_CONTAINER(setupdialog), 10);
-	GTK_WINDOW(setupdialog)->position = GTK_WIN_POS_MOUSE;
-	gtk_window_set_title(GTK_WINDOW(setupdialog), _("Gnome Mines setup"));
 	gtk_signal_connect(GTK_OBJECT(setupdialog),
 			   "delete_event",
 			   GTK_SIGNAL_FUNC(setupdialog_destroy),
 			   0);
 
-	all_boxes = gtk_vbox_new(FALSE, 5);
-	gtk_container_add(GTK_CONTAINER(setupdialog), all_boxes);
+	all_boxes = GNOME_DIALOG (setupdialog)->vbox;
 
         cframe = gtk_frame_new(_("Custom size"));
 
@@ -290,7 +290,7 @@ void setup_game(GtkWidget *widget, gpointer data)
 	gtk_container_add(GTK_CONTAINER(frame), box);
 	
 	button = gtk_radio_button_new_with_label(NULL, _("Tiny"));
-	if (fsize == 0) gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON (button), TRUE);
+	if (fsize == 0) gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(size_radio_callback),
 			   (gpointer) 0);
 	gtk_box_pack_start(GTK_BOX(box), button, TRUE, TRUE, 0);
@@ -298,7 +298,7 @@ void setup_game(GtkWidget *widget, gpointer data)
 
 	button = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(button)),
 						 _("Medium"));
-	if (fsize == 1) gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON (button), TRUE);
+	if (fsize == 1) gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(size_radio_callback),
 			   (gpointer) 1);
 	gtk_box_pack_start(GTK_BOX(box), button, TRUE, TRUE, 0);
@@ -306,7 +306,7 @@ void setup_game(GtkWidget *widget, gpointer data)
 
 	button = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(button)),
 						 _("Biiiig"));
-	if (fsize == 2) gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON (button), TRUE);
+	if (fsize == 2) gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(size_radio_callback),
 			   (gpointer) 2);
 	gtk_box_pack_start(GTK_BOX(box), button, TRUE, TRUE, 0);
@@ -314,7 +314,7 @@ void setup_game(GtkWidget *widget, gpointer data)
 	
 	button = gtk_radio_button_new_with_label(gtk_radio_button_group(GTK_RADIO_BUTTON(button)),
 						 _("Custom"));
-	if (fsize == 3) gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON (button), TRUE);
+	if (fsize == 3) gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON (button), TRUE);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(size_radio_callback),
 			   (gpointer) 3);
 	gtk_box_pack_start(GTK_BOX(box), button, TRUE, TRUE, 0);
@@ -394,17 +394,10 @@ void setup_game(GtkWidget *widget, gpointer data)
 	
 	box = gtk_hbox_new(TRUE, 5);
 	gtk_box_pack_start(GTK_BOX(all_boxes), box, TRUE, TRUE, 0);
-        button = gnome_stock_button(GNOME_STOCK_BUTTON_OK);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-			   GTK_SIGNAL_FUNC(do_setup), NULL);
-	gtk_box_pack_start(GTK_BOX(box), button, TRUE, TRUE, 5);
-        gtk_widget_show(button);
-        button = gnome_stock_button(GNOME_STOCK_BUTTON_CANCEL);
-	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                           (GtkSignalFunc)setupdialog_destroy,
-			   (gpointer)1);
-	gtk_box_pack_start(GTK_BOX(box), button, TRUE, TRUE, 5);
-        gtk_widget_show(button);
+	gnome_dialog_button_connect (GNOME_DIALOG (setupdialog), 0,
+			GTK_SIGNAL_FUNC (do_setup), NULL);
+	gnome_dialog_button_connect (GNOME_DIALOG (setupdialog), 1,
+			GTK_SIGNAL_FUNC (setupdialog_destroy), (gpointer) 1);
         gtk_widget_show(box);
 	
 	gtk_widget_show(all_boxes);
@@ -414,15 +407,12 @@ void setup_game(GtkWidget *widget, gpointer data)
 	gtk_widget_show(setupdialog);
 }
 
-GnomeUIInfo filemenu[] = {
-	GNOMEUIINFO_MENU_EXIT_ITEM(quit_game, NULL),
-	GNOMEUIINFO_END
-};
-
 GnomeUIInfo gamemenu[] = {
         GNOMEUIINFO_MENU_NEW_GAME_ITEM(new_game, NULL),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_SCORES_ITEM(top_ten, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_MENU_EXIT_ITEM(quit_game, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -438,7 +428,6 @@ GnomeUIInfo helpmenu[] = {
 };
 
 GnomeUIInfo mainmenu[] = {
-        GNOMEUIINFO_MENU_FILE_TREE(filemenu),
         GNOMEUIINFO_MENU_GAME_TREE(gamemenu),
 	GNOMEUIINFO_MENU_SETTINGS_TREE(settingsmenu),
         GNOMEUIINFO_MENU_HELP_TREE(helpmenu),
